.. _credits-label:

Credits
=======

Please reference: M. Maly, K. Diederichs, J. Dohnalek, P. Kolenko: `Paired refinement under the control of PAIREF <https://journals.iucr.org/m/issues/2020/04/00/mf5044/index.html>`_ (2020) *IUCrJ* **7**

*PAIREF* is developed by Martin Malý (1,2), `martin.maly@fjfi.cvut.cz <mailto:martin.maly@fjfi.cvut.cz>`_. Collaborators: Petr Kolenko (1,2), Jan Dohnálek (2), Kay Diederichs (3).

 1. `Laboratory of Structural Biology <http://kmlinux.fjfi.cvut.cz/~kolenpe1/>`_, Department of Solid State Engineering, Faculty of Nuclear Sciences and Physical Engineering, Czech Technical University in Prague

 2. `Laboratory of Structure and Fuction of Biomolecules <http://www.ibt.cas.cz/vyzkum/laboratore/laborator-struktury-a-funkce-biomolekul/index.html>`_, Institute of Biotechnology, BIOCEV, Czech Academy of Sciences

 3. `Department of Biology <https://www.biologie.uni-konstanz.de/diederichs/>`_, University of Konstanz

The program logo was designed by Tomáš Kalík.
